.. _install:
===========================
Installing ``pyXMIP``
===========================

Installing From PyPy
--------------------

``pyXMIP`` may be installed from PyPI (stable versions) as follows:

.. code-block:: shell

    >>> pip install pyxmip

Installing From Source
----------------------


To install ``pyXMIP`` from source, you need only clone the git repository

.. code-block:: shell

    >>> git clone https://www.github.com/eliza-diggins/pyXMIP

and then install using

.. code-block:: shell

    >>> cd pyXMIP
    >>> pip install .

You can also achieve this in one line using

.. code-block:: shell

    >>> pip install git+https://www.github.com/eliza-diggins/pyXMIP.git
